import {InMemoryCache}from'@apollo/client/cache/index.js';// cache.ts
const createCache = ({ getDataIdFromObject, clientState }) => {
    const cache = new InMemoryCache({
        dataIdFromObject: getDataIdFromObject,
        possibleTypes: clientState.possibleTypes,
        typePolicies: clientState.typePolicies,
    });
    return cache;
};
const initializeCache = ({ cache, initialState, clientState, logger }) => {
    if (initialState) {
        try {
            cache.restore(initialState);
            logger.debug('Cache restored with initial state');
        }
        catch (err) {
            logger.error(err, 'Error restoring cache');
        }
    }
    else {
        clientState.defaults?.forEach((x) => {
            try {
                if (x.type === 'query') {
                    cache.writeQuery({ query: x.query, data: x.data });
                }
                else if (x.type === 'fragment') {
                    cache.writeFragment({ id: x.id, fragment: x.fragment, data: x.data });
                }
            }
            catch (err) {
                logger.error(err, 'Error writing to cache');
            }
        });
    }
};export{createCache,initializeCache};